@@ -77,17 +77,16 @@ if TYPE_CHECKING:
 _client_init_debug = ContextVar("client_init_debug")
 
 
-SDK_INFO = {
+SDK_INFO: "SDKInfo" = {
     "name": "sentry.python",  # SDK name will be overridden after integrations have been loaded with sentry_sdk.integrations.setup_integrations()
     "version": VERSION,
     "packages": [{"name": "pypi:sentry-sdk", "version": VERSION}],
-}  # type: SDKInfo
+}
 
 
-def _get_options(*args, **kwargs):
-    # type: (*Optional[str], **Any) -> Dict[str, Any]
+def _get_options(*args: "Optional[str]", **kwargs: "Any") -> "Dict[str, Any]":
     if args and (isinstance(args[0], (bytes, str)) or args[0] is None):
-        dsn = args[0]  # type: Optional[str]
+        dsn: "Optional[str]" = args[0]
         args = args[1:]
     else:
         dsn = None
@@ -178,41 +177,36 @@ class BaseClient:
     The basic definition of a client that is used for sending data to Sentry.
     """
 
-    spotlight = None  # type: Optional[SpotlightClient]
+    spotlight: "Optional[SpotlightClient]" = None
 
-    def __init__(self, options=None):
-        # type: (Optional[Dict[str, Any]]) -> None
-        self.options = options if options is not None else DEFAULT_OPTIONS  # type: Dict[str, Any]
+    def __init__(self, options: "Optional[Dict[str, Any]]" = None) -> None:
+        self.options: "Dict[str, Any]" = (
+            options if options is not None else DEFAULT_OPTIONS
+        )
 
-        self.transport = None  # type: Optional[Transport]
-        self.monitor = None  # type: Optional[Monitor]
-        self.log_batcher = None  # type: Optional[LogBatcher]
-        self.metrics_batcher = None  # type: Optional[MetricsBatcher]
+        self.transport: "Optional[Transport]" = None
+        self.monitor: "Optional[Monitor]" = None
+        self.log_batcher: "Optional[LogBatcher]" = None
+        self.metrics_batcher: "Optional[MetricsBatcher]" = None
 
-    def __getstate__(self, *args, **kwargs):
-        # type: (*Any, **Any) -> Any
+    def __getstate__(self, *args: "Any", **kwargs: "Any") -> "Any":
         return {"options": {}}
 
-    def __setstate__(self, *args, **kwargs):
-        # type: (*Any, **Any) -> None
+    def __setstate__(self, *args: "Any", **kwargs: "Any") -> None:
         pass
 
     @property
-    def dsn(self):
-        # type: () -> Optional[str]
+    def dsn(self) -> "Optional[str]":
         return None
 
     @property
-    def parsed_dsn(self):
-        # type: () -> Optional[Dsn]
+    def parsed_dsn(self) -> "Optional[Dsn]":
         return None
 
-    def should_send_default_pii(self):
-        # type: () -> bool
+    def should_send_default_pii(self) -> bool:
         return False
 
-    def is_active(self):
-        # type: () -> bool
+    def is_active(self) -> bool:
         """
         .. versionadded:: 2.0.0
 
@@ -220,52 +214,41 @@ class BaseClient:
         """
         return False
 
-    def capture_event(self, *args, **kwargs):
-        # type: (*Any, **Any) -> Optional[str]
+    def capture_event(self, *args: "Any", **kwargs: "Any") -> "Optional[str]":
         return None
 
-    def _capture_log(self, log):
-        # type: (Log) -> None
+    def _capture_log(self, log: "Log") -> None:
         pass
 
-    def _capture_metric(self, metric):
-        # type: (Metric) -> None
+    def _capture_metric(self, metric: "Metric") -> None:
         pass
 
-    def capture_session(self, *args, **kwargs):
-        # type: (*Any, **Any) -> None
+    def capture_session(self, *args: "Any", **kwargs: "Any") -> None:
         return None
 
     if TYPE_CHECKING:
 
         @overload
-        def get_integration(self, name_or_class):
-            # type: (str) -> Optional[Integration]
-            ...
+        def get_integration(self, name_or_class: str) -> "Optional[Integration]": ...
 
         @overload
-        def get_integration(self, name_or_class):
-            # type: (type[I]) -> Optional[I]
-            ...
+        def get_integration(self, name_or_class: "type[I]") -> "Optional[I]": ...
 
-    def get_integration(self, name_or_class):
-        # type: (Union[str, type[Integration]]) -> Optional[Integration]
+    def get_integration(
+        self, name_or_class: "Union[str, type[Integration]]"
+    ) -> "Optional[Integration]":
         return None
 
-    def close(self, *args, **kwargs):
-        # type: (*Any, **Any) -> None
+    def close(self, *args: "Any", **kwargs: "Any") -> None:
         return None
 
-    def flush(self, *args, **kwargs):
-        # type: (*Any, **Any) -> None
+    def flush(self, *args: "Any", **kwargs: "Any") -> None:
         return None
 
-    def __enter__(self):
-        # type: () -> BaseClient
+    def __enter__(self) -> "BaseClient":
         return self
 
-    def __exit__(self, exc_type, exc_value, tb):
-        # type: (Any, Any, Any) -> None
+    def __exit__(self, exc_type: "Any", exc_value: "Any", tb: "Any") -> None:
         return None
 
 
@@ -289,22 +272,20 @@ class _Client(BaseClient):
     Alias of :py:class:`sentry_sdk.Client`. (Was created for better intelisense support)
     """
 
-    def __init__(self, *args, **kwargs):
-        # type: (*Any, **Any) -> None
+    def __init__(self, *args: "Any", **kwargs: "Any") -> None:
         super(_Client, self).__init__(options=get_options(*args, **kwargs))
         self._init_impl()
 
-    def __getstate__(self):
-        # type: () -> Any
+    def __getstate__(self) -> "Any":
         return {"options": self.options}
 
-    def __setstate__(self, state):
-        # type: (Any) -> None
+    def __setstate__(self, state: "Any") -> None:
         self.options = state["options"]
         self._init_impl()
 
-    def _setup_instrumentation(self, functions_to_trace):
-        # type: (Sequence[Dict[str, str]]) -> None
+    def _setup_instrumentation(
+        self, functions_to_trace: "Sequence[Dict[str, str]]"
+    ) -> None:
         """
         Instruments the functions given in the list `functions_to_trace` with the `@sentry_sdk.tracing.trace` decorator.
         """
@@ -354,24 +335,21 @@ class _Client(BaseClient):
                     e,
                 )
 
-    def _init_impl(self):
-        # type: () -> None
+    def _init_impl(self) -> None:
         old_debug = _client_init_debug.get(False)
 
-        def _capture_envelope(envelope):
-            # type: (Envelope) -> None
+        def _capture_envelope(envelope: "Envelope") -> None:
             if self.spotlight is not None:
                 self.spotlight.capture_envelope(envelope)
             if self.transport is not None:
                 self.transport.capture_envelope(envelope)
 
         def _record_lost_event(
-            reason,  # type: str
-            data_category,  # type: EventDataCategory
-            item=None,  # type: Optional[Item]
-            quantity=1,  # type: int
-        ):
-            # type: (...) -> None
+            reason: str,
+            data_category: "EventDataCategory",
+            item: "Optional[Item]" = None,
+            quantity: int = 1,
+        ) -> None:
             if self.transport is not None:
                 self.transport.record_lost_event(
                     reason=reason,
@@ -485,8 +463,7 @@ class _Client(BaseClient):
             # need to check if it's safe to use them.
             check_uwsgi_thread_support()
 
-    def is_active(self):
-        # type: () -> bool
+    def is_active(self) -> bool:
         """
         .. versionadded:: 2.0.0
 
@@ -494,8 +471,7 @@ class _Client(BaseClient):
         """
         return True
 
-    def should_send_default_pii(self):
-        # type: () -> bool
+    def should_send_default_pii(self) -> bool:
         """
         .. versionadded:: 2.0.0
 
@@ -504,27 +480,23 @@ class _Client(BaseClient):
         return self.options.get("send_default_pii") or False
 
     @property
-    def dsn(self):
-        # type: () -> Optional[str]
+    def dsn(self) -> "Optional[str]":
         """Returns the configured DSN as string."""
         return self.options["dsn"]
 
     @property
-    def parsed_dsn(self):
-        # type: () -> Optional[Dsn]
+    def parsed_dsn(self) -> "Optional[Dsn]":
         """Returns the configured parsed DSN object."""
         return self.transport.parsed_dsn if self.transport else None
 
     def _prepare_event(
         self,
-        event,  # type: Event
-        hint,  # type: Hint
-        scope,  # type: Optional[Scope]
-    ):
-        # type: (...) -> Optional[Event]
-
-        previous_total_spans = None  # type: Optional[int]
-        previous_total_breadcrumbs = None  # type: Optional[int]
+        event: "Event",
+        hint: "Hint",
+        scope: "Optional[Scope]",
+    ) -> "Optional[Event]":
+        previous_total_spans: "Optional[int]" = None
+        previous_total_breadcrumbs: "Optional[int]" = None
 
         if event.get("timestamp") is None:
             event["timestamp"] = datetime.now(timezone.utc)
@@ -559,7 +531,7 @@ class _Client(BaseClient):
                     "event_processor", data_category="span", quantity=spans_delta
                 )
 
-            dropped_spans = event.pop("_dropped_spans", 0) + spans_delta  # type: int
+            dropped_spans: int = event.pop("_dropped_spans", 0) + spans_delta
             if dropped_spans > 0:
                 previous_total_spans = spans_before + dropped_spans
             if scope._n_breadcrumbs_truncated > 0:
@@ -622,7 +594,7 @@ class _Client(BaseClient):
                 event_scrubber.scrub_event(event)
 
         if scope is not None and scope._gen_ai_original_message_count:
-            spans = event.get("spans", [])  # type: List[Dict[str, Any]] | AnnotatedValue
+            spans: "List[Dict[str, Any]] | AnnotatedValue" = event.get("spans", [])
             if isinstance(spans, list):
                 for span in spans:
                     span_id = span.get("span_id", None)
@@ -716,8 +688,7 @@ class _Client(BaseClient):
 
         return event
 
-    def _is_ignored_error(self, event, hint):
-        # type: (Event, Hint) -> bool
+    def _is_ignored_error(self, event: "Event", hint: "Hint") -> bool:
         exc_info = hint.get("exc_info")
         if exc_info is None:
             return False
@@ -740,11 +711,10 @@ class _Client(BaseClient):
 
     def _should_capture(
         self,
-        event,  # type: Event
-        hint,  # type: Hint
-        scope=None,  # type: Optional[Scope]
-    ):
-        # type: (...) -> bool
+        event: "Event",
+        hint: "Hint",
+        scope: "Optional[Scope]" = None,
+    ) -> bool:
         # Transactions are sampled independent of error events.
         is_transaction = event.get("type") == "transaction"
         if is_transaction:
@@ -762,10 +732,9 @@ class _Client(BaseClient):
 
     def _should_sample_error(
         self,
-        event,  # type: Event
-        hint,  # type: Hint
-    ):
-        # type: (...) -> bool
+        event: "Event",
+        hint: "Hint",
+    ) -> bool:
         error_sampler = self.options.get("error_sampler", None)
 
         if callable(error_sampler):
@@ -810,11 +779,9 @@ class _Client(BaseClient):
 
     def _update_session_from_event(
         self,
-        session,  # type: Session
-        event,  # type: Event
-    ):
-        # type: (...) -> None
-
+        session: "Session",
+        event: "Event",
+    ) -> None:
         crashed = False
         errored = False
         user_agent = None
@@ -849,11 +816,10 @@ class _Client(BaseClient):
 
     def capture_event(
         self,
-        event,  # type: Event
-        hint=None,  # type: Optional[Hint]
-        scope=None,  # type: Optional[Scope]
-    ):
-        # type: (...) -> Optional[str]
+        event: "Event",
+        hint: "Optional[Hint]" = None,
+        scope: "Optional[Scope]" = None,
+    ) -> "Optional[str]":
         """Captures an event.
 
         :param event: A ready-made event that can be directly sent to Sentry.
@@ -864,7 +830,7 @@ class _Client(BaseClient):
 
         :returns: An event ID. May be `None` if there is no DSN set or of if the SDK decided to discard the event for other reasons. In such situations setting `debug=True` on `init()` may help.
         """
-        hint = dict(hint or ())  # type: Hint
+        hint: "Hint" = dict(hint or ())
 
         if not self._should_capture(event, hint, scope):
             return None
@@ -899,10 +865,10 @@ class _Client(BaseClient):
         trace_context = event_opt.get("contexts", {}).get("trace") or {}
         dynamic_sampling_context = trace_context.pop("dynamic_sampling_context", {})
 
-        headers = {
+        headers: "dict[str, object]" = {
             "event_id": event_opt["event_id"],
             "sent_at": format_timestamp(datetime.now(timezone.utc)),
-        }  # type: dict[str, object]
+        }
 
         if dynamic_sampling_context:
             headers["trace"] = dynamic_sampling_context
@@ -932,8 +898,7 @@ class _Client(BaseClient):
 
         return return_value
 
-    def _capture_log(self, log):
-        # type: (Optional[Log]) -> None
+    def _capture_log(self, log: "Optional[Log]") -> None:
         if not has_logs_enabled(self.options) or log is None:
             return
 
@@ -962,14 +927,11 @@ class _Client(BaseClient):
         if trace_id is not None and log.get("trace_id") is None:
             log["trace_id"] = trace_id
 
-        if (
-            span_id is not None
-            and "sentry.trace.parent_span_id" not in log["attributes"]
-        ):
-            log["attributes"]["sentry.trace.parent_span_id"] = span_id
+        if span_id is not None and log.get("span_id") is None:
+            log["span_id"] = span_id
 
         # The user, if present, is always set on the isolation scope.
-        if isolation_scope._user is not None:
+        if self.should_send_default_pii() and isolation_scope._user is not None:
             for log_attribute, user_attribute in (
                 ("user.id", "id"),
                 ("user.name", "username"),
@@ -1000,8 +962,7 @@ class _Client(BaseClient):
         if self.log_batcher:
             self.log_batcher.add(log)
 
-    def _capture_metric(self, metric):
-        # type: (Optional[Metric]) -> None
+    def _capture_metric(self, metric: "Optional[Metric]") -> None:
         if not has_metrics_enabled(self.options) or metric is None:
             return
 
@@ -1034,7 +995,7 @@ class _Client(BaseClient):
         if span_id is not None:
             metric["span_id"] = span_id
 
-        if isolation_scope._user is not None:
+        if self.should_send_default_pii() and isolation_scope._user is not None:
             for metric_attribute, user_attribute in (
                 ("user.id", "id"),
                 ("user.name", "username"),
@@ -1066,9 +1027,8 @@ class _Client(BaseClient):
 
     def capture_session(
         self,
-        session,  # type: Session
-    ):
-        # type: (...) -> None
+        session: "Session",
+    ) -> None:
         if not session.release:
             logger.info("Discarded session update because of missing release")
         else:
@@ -1077,20 +1037,15 @@ class _Client(BaseClient):
     if TYPE_CHECKING:
 
         @overload
-        def get_integration(self, name_or_class):
-            # type: (str) -> Optional[Integration]
-            ...
+        def get_integration(self, name_or_class: str) -> "Optional[Integration]": ...
 
         @overload
-        def get_integration(self, name_or_class):
-            # type: (type[I]) -> Optional[I]
-            ...
+        def get_integration(self, name_or_class: "type[I]") -> "Optional[I]": ...
 
     def get_integration(
         self,
-        name_or_class,  # type: Union[str, Type[Integration]]
-    ):
-        # type: (...) -> Optional[Integration]
+        name_or_class: "Union[str, Type[Integration]]",
+    ) -> "Optional[Integration]":
         """Returns the integration for this client by name or class.
         If the client does not have that integration then `None` is returned.
         """
@@ -1105,10 +1060,9 @@ class _Client(BaseClient):
 
     def close(
         self,
-        timeout=None,  # type: Optional[float]
-        callback=None,  # type: Optional[Callable[[int, float], None]]
-    ):
-        # type: (...) -> None
+        timeout: "Optional[float]" = None,
+        callback: "Optional[Callable[[int, float], None]]" = None,
+    ) -> None:
         """
         Close the client and shut down the transport. Arguments have the same
         semantics as :py:meth:`Client.flush`.
@@ -1127,10 +1081,9 @@ class _Client(BaseClient):
 
     def flush(
         self,
-        timeout=None,  # type: Optional[float]
-        callback=None,  # type: Optional[Callable[[int, float], None]]
-    ):
-        # type: (...) -> None
+        timeout: "Optional[float]" = None,
+        callback: "Optional[Callable[[int, float], None]]" = None,
+    ) -> None:
         """
         Wait for the current events to be sent.
 
@@ -1148,12 +1101,10 @@ class _Client(BaseClient):
                 self.metrics_batcher.flush()
             self.transport.flush(timeout=timeout, callback=callback)
 
-    def __enter__(self):
-        # type: () -> _Client
+    def __enter__(self) -> "_Client":
         return self
 
-    def __exit__(self, exc_type, exc_value, tb):
-        # type: (Any, Any, Any) -> None
+    def __exit__(self, exc_type: "Any", exc_value: "Any", tb: "Any") -> None:
         self.close()
 
 
