@@ -9,22 +9,19 @@ from logging import LogRecord
 
 
 class _DebugFilter(logging.Filter):
-    def filter(self, record):
-        # type: (LogRecord) -> bool
+    def filter(self, record: "LogRecord") -> bool:
         if _client_init_debug.get(False):
             return True
 
         return get_client().options["debug"]
 
 
-def init_debug_support():
-    # type: () -> None
+def init_debug_support() -> None:
     if not logger.handlers:
         configure_logger()
 
 
-def configure_logger():
-    # type: () -> None
+def configure_logger() -> None:
     _handler = logging.StreamHandler(sys.stderr)
     _handler.setFormatter(logging.Formatter(" [sentry] %(levelname)s: %(message)s"))
     logger.addHandler(_handler)
@@ -32,8 +29,7 @@ def configure_logger():
     logger.addFilter(_DebugFilter())
 
 
-def configure_debug_hub():
-    # type: () -> None
+def configure_debug_hub() -> None:
     warnings.warn(
         "configure_debug_hub is deprecated. Please remove calls to it, as it is a no-op.",
         DeprecationWarning,
