@@ -18,8 +18,8 @@ from sentry_sdk.integrations.grpc.consts import SPAN_ORIGIN
 class ClientInterceptor:
     @staticmethod
     def _update_client_call_details_metadata_from_scope(
-        client_call_details: ClientCallDetails,
-    ) -> ClientCallDetails:
+        client_call_details: "ClientCallDetails",
+    ) -> "ClientCallDetails":
         if client_call_details.metadata is None:
             client_call_details = client_call_details._replace(metadata=Metadata())
         elif not isinstance(client_call_details.metadata, Metadata):
@@ -39,10 +39,10 @@ class ClientInterceptor:
 class SentryUnaryUnaryClientInterceptor(ClientInterceptor, UnaryUnaryClientInterceptor):  # type: ignore
     async def intercept_unary_unary(
         self,
-        continuation: Callable[[ClientCallDetails, Message], UnaryUnaryCall],
-        client_call_details: ClientCallDetails,
-        request: Message,
-    ) -> Union[UnaryUnaryCall, Message]:
+        continuation: "Callable[[ClientCallDetails, Message], UnaryUnaryCall]",
+        client_call_details: "ClientCallDetails",
+        request: "Message",
+    ) -> "Union[UnaryUnaryCall, Message]":
         method = client_call_details.method
 
         with sentry_sdk.start_span(
@@ -70,10 +70,10 @@ class SentryUnaryStreamClientInterceptor(
 ):
     async def intercept_unary_stream(
         self,
-        continuation: Callable[[ClientCallDetails, Message], UnaryStreamCall],
-        client_call_details: ClientCallDetails,
-        request: Message,
-    ) -> Union[AsyncIterable[Any], UnaryStreamCall]:
+        continuation: "Callable[[ClientCallDetails, Message], UnaryStreamCall]",
+        client_call_details: "ClientCallDetails",
+        request: "Message",
+    ) -> "Union[AsyncIterable[Any], UnaryStreamCall]":
         method = client_call_details.method
 
         with sentry_sdk.start_span(
