@@ -66,21 +66,20 @@ SEVERITY_TO_OTEL_SEVERITY = {
 class LoguruIntegration(Integration):
     identifier = "loguru"
 
-    level = DEFAULT_LEVEL  # type: Optional[int]
-    event_level = DEFAULT_EVENT_LEVEL  # type: Optional[int]
+    level: "Optional[int]" = DEFAULT_LEVEL
+    event_level: "Optional[int]" = DEFAULT_EVENT_LEVEL
     breadcrumb_format = DEFAULT_FORMAT
     event_format = DEFAULT_FORMAT
-    sentry_logs_level = DEFAULT_LEVEL  # type: Optional[int]
+    sentry_logs_level: "Optional[int]" = DEFAULT_LEVEL
 
     def __init__(
         self,
-        level=DEFAULT_LEVEL,
-        event_level=DEFAULT_EVENT_LEVEL,
-        breadcrumb_format=DEFAULT_FORMAT,
-        event_format=DEFAULT_FORMAT,
-        sentry_logs_level=DEFAULT_LEVEL,
-    ):
-        # type: (Optional[int], Optional[int], str | loguru.FormatFunction, str | loguru.FormatFunction, Optional[int]) -> None
+        level: "Optional[int]" = DEFAULT_LEVEL,
+        event_level: "Optional[int]" = DEFAULT_EVENT_LEVEL,
+        breadcrumb_format: "str | loguru.FormatFunction" = DEFAULT_FORMAT,
+        event_format: "str | loguru.FormatFunction" = DEFAULT_FORMAT,
+        sentry_logs_level: "Optional[int]" = DEFAULT_LEVEL,
+    ) -> None:
         LoguruIntegration.level = level
         LoguruIntegration.event_level = event_level
         LoguruIntegration.breadcrumb_format = breadcrumb_format
@@ -88,8 +87,7 @@ class LoguruIntegration(Integration):
         LoguruIntegration.sentry_logs_level = sentry_logs_level
 
     @staticmethod
-    def setup_once():
-        # type: () -> None
+    def setup_once() -> None:
         if LoguruIntegration.level is not None:
             logger.add(
                 LoguruBreadcrumbHandler(level=LoguruIntegration.level),
@@ -112,8 +110,7 @@ class LoguruIntegration(Integration):
 
 
 class _LoguruBaseHandler(_BaseHandler):
-    def __init__(self, *args, **kwargs):
-        # type: (*Any, **Any) -> None
+    def __init__(self, *args: "Any", **kwargs: "Any") -> None:
         if kwargs.get("level"):
             kwargs["level"] = SENTRY_LEVEL_FROM_LOGURU_LEVEL.get(
                 kwargs.get("level", ""), DEFAULT_LEVEL
@@ -121,8 +118,7 @@ class _LoguruBaseHandler(_BaseHandler):
 
         super().__init__(*args, **kwargs)
 
-    def _logging_to_event_level(self, record):
-        # type: (LogRecord) -> str
+    def _logging_to_event_level(self, record: "LogRecord") -> str:
         try:
             return SENTRY_LEVEL_FROM_LOGURU_LEVEL[
                 LoggingLevels(record.levelno).name
@@ -143,8 +139,7 @@ class LoguruBreadcrumbHandler(_LoguruBaseHandler, BreadcrumbHandler):
     pass
 
 
-def loguru_sentry_logs_handler(message):
-    # type: (Message) -> None
+def loguru_sentry_logs_handler(message: "Message") -> None:
     # This is intentionally a callable sink instead of a standard logging handler
     # since otherwise we wouldn't get direct access to message.record
     client = sentry_sdk.get_client()
@@ -167,7 +162,7 @@ def loguru_sentry_logs_handler(message):
         record["level"].no, SEVERITY_TO_OTEL_SEVERITY
     )
 
-    attrs = {"sentry.origin": "auto.log.loguru"}  # type: dict[str, Any]
+    attrs: "dict[str, Any]" = {"sentry.origin": "auto.log.loguru"}
 
     project_root = client.options["project_root"]
     if record.get("file"):
@@ -209,5 +204,6 @@ def loguru_sentry_logs_handler(message):
             "attributes": attrs,
             "time_unix_nano": int(record["time"].timestamp() * 1e9),
             "trace_id": None,
+            "span_id": None,
         }
     )
